@@ -1,4 +1,5 @@
 import socket
+from typing import Union
 
 from plogger import logger
 
@@ -127,7 +128,7 @@ class SocketClient:
         except AttributeError as err:
             self.logger.error(f'[{self.host}] {err}')
 
-    def _receive_all(self, timeout: float = None, buffer_size: int = 4096):
+    def _receive_all(self, timeout: Union[float, None] = None, buffer_size: int = 4096):
         """Get and decode socket response
 
         :param timeout: Read timeout
@@ -149,7 +150,7 @@ class SocketClient:
                     data.extend(chunk)
             except socket.timeout:
                 self.logger.debug(f'[{self.host} <--] Socket read timeout ({timeout})')
-                self.client.settimeout(0)
+                self.client.settimeout(None)  # Set blocking
 
         response = data.decode().strip().split('\n')
         self.logger.info(f'[{self.host} <--] {response}')
